# Description

library wrapper for ml libraries.

### Сapabilities
The main class is a conveyor as an analogue of a pipeline. There is a partial interchangeability. The focus is on expanding built-in capabilities such as auto-typing predictive models, feature importance inference, scores, and various future features. There are also adapted transformers, classes for customizing the structure of projects.

### Status
At the moment, the functionality is not wide, designed for expansion in the future